# TE-SYSTEMS GmbH
# Script date: May 2024

# This script performs the following actions:
# 	- Import the configuration for which the path was defined into the defined anynode.
#	- If so defined, the configuration is committed to anynode.

# In order to use the script, some variables must be adjusted.
#	- The path to the REST API PowerShell-Module must be set.
#		By default, the Powershell-Modul is in the folder directly above the one in which this script is located.
#	- The address of  anynode must be set.
#		By default the address is set to localhost.

#   --- Config import ---
#   - The path to the .xzconfig file that is to be imported must be set.
#   - It must be determined whether the imported configuration should be comitted.
#		In an unadapted state, the imported configuration won't be committed.

# Please check all existing parameters before starting the script.

# Set execution environment
Set-ExecutionPolicy -ExecutionPolicy Unrestricted -Scope Process

#---- Variables ----
# The path to the REST API PowerShell-Module must be specified. In this case. 
# 	In this case it is in the folder above the one where this script is located.
Import-Module "./../anynode_rest_api_powershell.psm1"

# Define anynode's Address and Port.
$AnynodeAddress='127.0.0.1'
$AnynodePort=443

# The Path to the .xzconfig file must be specified.
$ConfigPath="PATH_TO_CONFIG"

# Set this parameter to $true to automatically commit the imported configuration.
$CommitConfig=$false

# If you have not established a secure connection (HTTPS) to anynode,
# you can use HTTP instead.
# This is not recommended, since your data will NOT be encrypted!
# To activate it anyway, uncomment the following line:
# Disable-CertificateCheck

# Authentication
$Cred=Get-Credential


# ----------- Start of script -----------
try {
    # Importing the configuration to anynode.
    Import-anynodeConfig -Address $AnynodeAddress -Port $AnynodePort -Credential $Cred -Filepath $ConfigPath	
} catch {
	$_.Exception.Message
	pause
	return
}

	# Commiting imported config if variable "$commitConfig" is set to "true"
if($CommitConfig -eq $true) {
	Push-anynodeConfig -Address $AnynodeAddress -Port $AnynodePort -Credential $Cred
	echo "commit done"
	pause
}