#!bin/bash

# TE-SYSTEMS GmbH
# Script date: May 2024

# The following actions are performed by this script:
# 	- Export of an backup of the anynode configuration

# This script uses curl.
#  In case curl does not trust your web certificate, this script will not work. Please
#  edit all curl commands after the ---- Start of script ---- part to make it work.

# In order to use the script, some variables must be adjusted.
#	- The path to the REST API PowerShell-Module must be set.
#		By default, the Powershell-Modul is in the folder directly above the one in which this script is located.
#	- The address of  anynode must be set.
#		By default the address is set to localhost.

#  	--- Config backup export ---
#   - The path the backup should be saved at must be defined.
# 	- The data the backup should include can be adjusted.
# 		For all available parameters view the REST API documentation.

# Please check all existing parameters before starting the script.
#---- Variables ----
# Define anynode's address and port.
anynode='127.0.0.1'

# Put in credentials of a user with configuration write access and REST API access.
cred='anadmin:password'

# Define the path, the backup file should be saved at.
path='YOU_EXPORT_PATH'

# The data the backup should include.
# For all available parameters view the REST API documentation.
backupParameter=$(cat << END 
{
	"includedData":[ 
		"ANYNODE_CONFIG",
        "MEDIA_FILES",
        "HTTP_SERVER_FILES",
        "FRONTEND_CONFIG",
        "MONITOR_CONFIG",
        "CALL_HISTORY",
        "EVENT_LOG"
    ]
}
END
)

# ---- Start of script ----
# The next 4 lines check whether a secure connection can be established.
# In order to establish an insecure connection, the following must be adjusted
#	- Delete the following 4 lines or comment them out
#	- Adjust all following curl commands 

ssl=$(curl -s https://$anynode/)
if [[ $ssl == "" ]]; then
  echo 'No secure connection could be established to anynode.'
fi

# Timestamp data
backupDate=$(date +'%Y_%m_%d_%H_%M_%S')

# Creates a backup of the anynode configuration
# If you want to use an insecure connection, add the -k argument for curl
curl -s -k -u $cred -d "$backupParameter" -H 'Content-Type: application/json' -H 'Accept: application/json' https://$anynode/api/backup?version=0 >> "${path}/cs_anynode_backup${backupDate}.zip"


