#!bin/bash

# TE-SYSTEMS GmbH
# Script date: May 2024

# This script performs the following actions:
# 	- Import the configuration for which the path was defined into the defined anynode.
#	- Import the LOD license to anynode.
#	- If so defined, the configuration is committed to anynode.

# This script uses cat, curl and jq. 
#  In case curl does not trust your web certificate, this script will not work. Please
#  edit all curl commands after the ---- Start of script ---- part to make it work.
# 	- curl might not be installed by default - to install curl use sudo apt install curl in terminal
#	- cat should be installed with linux by default
#	- jq might not be installed by default - to install jq use sudo apt install jq in terminal

# In order to use the script, some variables must be adjusted.
#	- The path to the REST API PowerShell-Module must be set.
#		By default, the Powershell-Modul is in the folder directly above the one in which this script is located.
#	- The address of  anynode must be set.
#		By default the address is set to localhost.

#   --- Config import ---
#   - The path to the .xzconfig file that is to be imported must be set.
#   - It must be determined whether the imported configuration should be comitted.
#		In an unadapted state, the imported configuration won't be committed.

#   --- LOD license import ---
#   - An email address must be specified for LOD activation.
#   - A company name must be specified for LOD activation.
#	- The LOD Key must be entered.

# Please check all existing parameters before starting the script.

#---- Variables ----
# Define anynode's address and port.
anynode='127.0.0.1:443'

# Set the credentials of an anynode user with configuration write access and REST API access.
cred='USERNAME:PASSWORD'

# The Path to the .xzconfig file must be specified.
configPath="PATH_TO_CONFIG"

# Set this parameter to $true to automatically commit the imported configuration.
commitConfig=false

# Set the required details of the LOD.
emailAddress="EMAIL"
companyName="COMPANY_NAME"
lodKey="LOD_KEY"

# ---- Start of script ----
# The next 4 lines check whether a secure connection can be established.
# In order to establish an insecure connection, the following must be adjusted
#	- Delete the following 4 lines or comment them out
#	- Adjust all following curl commands 

ssl=$(curl -s https://$anynode/)
if [[ $ssl == "" ]]; then
  echo 'No secure connection could be established to anynode.'
fi

# Use the given data to create the lodDataObject
lodData=$(cat <<EOF
{
	"emailAddress": "${emailAddress}",
	"companyName": "${companyName}",
	"lodKey": "${lodKey}"
}
EOF
)

# Import the config to anynode
# If you want to use an insecure connection, add the -k argument for curl
echo "--- Importing the given configuration to anynode."
curl -k -s -u ${cred} -H "Content-Type: multipart/form-data" -X PUT http://${anynode}/api/anynodeConfig/set?version=0 -F "file=@${configPath}"

# Get the devices System ID's and select the first
systemIds=$(curl -k -s -u ${cred} -X GET http://${anynode}/api/licenses/systemIds/get?version=0)
licensingDeviceID=$(echo "$systemIds" | jq '.[0].id' | sed 's/^"\(.*\)"$/\1/')

# Add the System ID of the first device to lodData
updatedLodData=$(echo "$lodData" | jq --arg licensingDeviceID "$licensingDeviceID" ' . + { "licensingDevice": $licensingDeviceID }')

# Import the LOD 
# If you want to use an insecure connection, add the -k argument for curl
echo "--- Importing LOD license to anynode - this can take up to 30 seconds."
curl -k -s -u ${cred} -H "Content-Type: application/json" -d "${updatedLodData}" -X PUT http://${anynode}/api/licenses/importLod?version=0 > /dev/null
echo "--- LOD license successfully imported."

# Commiting imported config if variable "$commitConfig" is set to "true"
# If you want to use an insecure connection, add the -k argument for curl
if [ $commitConfig = true ] ; then
echo "--- Committing the configuration."
curl -k -s -u ${cred} -X POST http://{$anynode}/api/anynodeConfig/commit?version=0
echo "--- Committed anynode config to ${anynode} successfully."
fi

